@@ -20,14 +20,19 @@
 #include "sol.h"
 #include "card.h"
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <games-card-pixmaps.h>
 
 GdkPixmap *default_background_pixmap; 
 GdkPixbuf *slot_pixbuf;
-GdkBitmap *mask;
+GdkPixmap *slot_pixmap = NULL;
+GdkBitmap *mask = NULL;
+GdkBitmap *slot_mask = NULL;
+
+GamesCardPixmaps * images = NULL;
 
 GdkPixmap* get_card_picture (gint suit, gint rank ) 
 {
-  return gdk_card_deck_face (GDK_CARD_DECK (card_deck), suit, (rank == 14)?1:rank);
+  return games_card_pixmaps_get_card (images, suit, rank);
 }
 
 GdkPixmap* get_background_pixmap () {
@@ -35,42 +40,12 @@ GdkPixmap* get_background_pixmap () {
   return default_background_pixmap;
 }
 
-GdkPixbuf* get_slot_pixbuf () {
-  return slot_pixbuf;
+GdkPixmap* get_slot_pixmap () {
+  return slot_pixmap;
 }
 
 GdkPixmap* get_card_back_pixmap () {
-  return gdk_card_deck_back (GDK_CARD_DECK (card_deck));
-}
-
-int get_card_width () {
-  int width, height;
-  gdk_drawable_get_size(gdk_card_deck_back (GDK_CARD_DECK (card_deck)), 
-		      &width, &height);
-  return width;
-}
-
-int get_card_height () {
-  int width, height;
-  gdk_drawable_get_size(gdk_card_deck_back (GDK_CARD_DECK (card_deck)), 
-		      &width, &height);
-  return height;
-}
-
-int get_horiz_offset () {
-  return get_card_width() + x_spacing;
-}
-
-int get_vert_offset () {
-  return get_card_height() + y_spacing;
-}
-
-int get_vert_start () {
-  return 30;
-}
-
-int get_horiz_start () {
-  return 30;
+  return games_card_pixmaps_get_back (images);
 }
 
 static GdkPixmap* get_pixmap (const char* filename)
@@ -112,29 +87,14 @@ static GdkPixbuf* get_pixbuf (const char* filename)
   return im;
 }
 
-void load_pixmaps (GtkWidget* app, GdkCardDeckOptions deck_options) 
+void load_pixmaps (void) 
 {
-  card_deck = gdk_card_deck_new (app->window, deck_options);
-  if (card_deck == NULL) {
-    GtkWidget * error_dialog;
-    
-    error_dialog = gtk_message_dialog_new(GTK_WINDOW (app), GTK_DIALOG_MODAL,
-                                          GTK_MESSAGE_ERROR,
-                                          GTK_BUTTONS_CLOSE,
-                                          N_("AisleRiot could not load its deck images.\n\nAisleRiot will now exit."));
-    gtk_dialog_run (GTK_DIALOG (error_dialog));
-    gtk_widget_destroy(error_dialog);
-    exit(1);
-  }
-  
-  mask = gdk_card_deck_mask (GDK_CARD_DECK (card_deck)); 
   slot_pixbuf = get_pixbuf ("cards/slots/plain.png");
   default_background_pixmap = get_pixmap ("cards/baize.png");
 }
 
 void free_pixmaps () 
 {
-  gtk_object_destroy (card_deck);
   if (slot_pixbuf != NULL)
     gdk_pixbuf_unref (slot_pixbuf);
   if (default_background_pixmap != NULL)
@@ -149,3 +109,37 @@ void add_card(GList** card_list, hcard_type temp_card) {
 	 (*card_list)->data = temp_card;
   }
 }
+
+void set_card_size (gint width, gint height)
+{
+  GdkPixbuf *scaled;
+
+  if (slot_pixmap)
+    g_object_unref (slot_pixmap);
+  if (slot_mask)
+    g_object_unref (slot_mask);
+
+  scaled = gdk_pixbuf_scale_simple (slot_pixbuf, width, height, 
+				    GDK_INTERP_BILINEAR);
+
+  gdk_pixbuf_render_pixmap_and_mask (scaled, &slot_pixmap, &slot_mask, 255);
+
+  gdk_gc_set_clip_mask (slot_gc, slot_mask); 
+
+  g_object_unref (scaled);
+
+  if (!images) {
+    images = games_card_pixmaps_new (playing_area->window);
+    games_card_pixmaps_set_theme (images, card_style); 
+  }
+  games_card_pixmaps_set_size (images, width, height);  
+  mask = games_card_pixmaps_get_mask (images);
+  gdk_gc_set_clip_mask (draw_gc, mask);
+}
+
+void set_card_theme (gchar * theme)
+{
+  games_card_pixmaps_set_theme (images, theme);
+  mask = games_card_pixmaps_get_mask (images);
+  gdk_gc_set_clip_mask (draw_gc, mask);  
+}
