@@ -37,8 +37,6 @@ int waiting_for_mouse_up(void) {
   return 0;
 }
 
-/* Button press statuses */
-
 void end_of_game_test() {
 
   gh_eval_str ("(end-move)");
@@ -63,8 +61,8 @@ void drop_moving_cards(gint x, gint y) {
   gint cardid, moved = 0;
   gint width, height;
 
-  slot_pressed(x + get_card_width() / 2 - press_data->xoffset, 
-	       y + get_card_height() / 2 - press_data->yoffset, 
+  slot_pressed(x + card_width / 2 - press_data->xoffset, 
+	       y + card_height / 2 - press_data->yoffset, 
 	       &hslot, &cardid);
 
   if (hslot) {
@@ -88,8 +86,8 @@ void drop_moving_cards(gint x, gint y) {
 
   gdk_drawable_get_size(press_data->moving_cards, &width, &height);
   gdk_window_move(press_data->moving_cards, 
-		  hslot->x + hslot->width - width, 
-		  hslot->y + hslot->height - height);
+		  hslot->pixelx + hslot->width - width, 
+		  hslot->pixely + hslot->height - height);
 
   refresh_screen();
 
@@ -145,8 +143,8 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
     if (card->direction == UP) {      
       guint delta = hslot->exposed - (hslot->length - cardid) - 1;
-      int x = hslot->x + delta * hslot->dx;
-      int y = hslot->y + delta * hslot->dy;
+      int x = hslot->pixelx + delta * hslot->pixeldx;
+      int y = hslot->pixely + delta * hslot->pixeldy;
 
       press_data->status = STATUS_SHOW;
       press_data->moving_pixmap = get_card_picture (card->suit, card->value);
@@ -258,23 +256,32 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
   return FALSE;
 }
 
+gint app_configure_event (GtkWidget *widget, GdkEventConfigure *event) {
+  GConfClient * gconf_client = gconf_client_get_default ();
+
+  gconf_client_set_int (gconf_client, WIDTH_GCONF_KEY, event->width, NULL);
+  gconf_client_set_int (gconf_client, HEIGHT_GCONF_KEY, event->height, NULL);
+
+  return FALSE;
+}
+
 gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
   gint tmptime;
   GtkSettings * settings;
 
   if(surface) {
-    gint old_w, old_h;
-
-    gdk_drawable_get_size(surface, &old_w, &old_h);
-    if(old_w == event->width && old_h == event->height)
+    if(window_width == event->width && window_height == event->height)
       return TRUE;
     g_object_unref(surface);
   }
 
+  window_width = event->width;
+  window_height = event->height;
+
   surface =
-    gdk_pixmap_new (playing_area->window, event->width, event->height,
-		    gdk_drawable_get_visual (playing_area->window)->depth);
-  
+    gdk_pixmap_new (playing_area->window, window_width, window_height, -1);
+
+  rescale_cards ();
   refresh_screen();
 
   /* Set up the double-click detection.*/
@@ -283,7 +290,7 @@ gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
   settings = gtk_settings_get_default();
   g_object_get(G_OBJECT(settings),"gtk-double-click-time",&tmptime,NULL);
   dbl_click_time = tmptime/1000.0;
-  
+ 
   return FALSE;
 }
 
